execute_batch

Function execute_batch 

pub fn execute_batch<'a>(
    batch: &'a TransactionBatchWithIndexes<'_, '_, impl TransactionWithMeta>,
    bank: &'a Arc<Bank>,
    transaction_status_sender: Option<&'a TransactionStatusSender>,
    replay_vote_sender: Option<&'a ReplayVoteSender>,
    timings: &'a mut ExecuteTimings,
    log_messages_bytes_limit: Option<usize>,
    prioritization_fee_cache: &'a PrioritizationFeeCache,
    extra_pre_commit_callback: Option<impl FnOnce(&TransactionResult<ProcessedTransaction>) -> TransactionResult<Option<usize>>>,
) -> TransactionResult<()>
👎Deprecated since 3.1.0:

This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.